@@ -1,7 +1,7 @@
 package Message::Passing::Input::Redis;
 use Moose;
 use Scalar::Util qw/ weaken /;
-use Message::Passing::Redis::Types qw/ ArrayOfStr /;
+use Message::Passing::Types qw/ ArrayOfStr /;
 use namespace::autoclean;
 
 with qw/
@@ -69,7 +69,7 @@ Message::Passing::Input::Redis - A Redis consumer for Message::Passing
 
 =head1 SYNOPSIS
 
-    $ message-passing --output STDOUT --input Redis --input_options '{"topics":["foo"],"server":"127.0.0.1:6379"}'
+    $ message-passing --output STDOUT --input Redis --input_options '{"topics":["foo"],"hostname":"127.0.0.1","port":"6379"}'
 
 =head1 DESCRIPTION
 
@@ -77,9 +77,13 @@ A simple subscriber a Redis PubSub topic
 
 =head1 ATTRIBUTES
 
-=head2 server
+=head2 hostname
 
-The hostname and port number of the Redis server. Defaults to C<< 127.0.0.1:6379 >>.
+The hostname of the Redis server. Required.
+
+=head2 port
+
+The port number of the Redis server. Defaults to 6379.
 
 =head2 topics
 
