@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Redis;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 $VERSION = eval $VERSION;
 
 1;
@@ -15,11 +15,11 @@ Message::Passing::Redis - Produce or consume messages by Redis PubSub
 =head1 SYNOPSIS
 
     # Terminal 1:
-    $ message-passing --input STDIN --output Redis --output_options '{"topic":"foo","server":"127.0.0.1:6379"}'
+    $ message-passing --input STDIN --output Redis --output_options '{"topic":"foo","hostname":"127.0.0.1","port":"6379"}'
     {"data":{"some":"data"},"@metadata":"value"}
 
     # Terminal 2:
-    $ message-passing --output STDOUT --input Redis --input_options '{"topics":["foo"],"server":"127.0.0.1:6379"}'
+    $ message-passing --output STDOUT --input Redis --input_options '{"topics":["foo"],"hostname":"127.0.0.1","port":"6379"}'
     {"data":{"some":"data"},"@metadata":"value"}
 
 =head1 DESCRIPTION
